#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: urls.py 10806 2018-03-02 04:29:05Z David $
#
# Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2018-03-02 12:29:05 +0800 (Fri, 02 Mar 2018) $
# $Revision: 10806 $

from django.conf.urls import url, patterns

from Theophrastus.editor import views

urlpatterns = patterns('',
    url(r'^templates/(?P<name>[-\w]+)/', views.getTemplate,
        name='Theophrastus.views.getTemplate'),
    url(r'^upload/display/$', views.uploadFile,
        name='Theophrastus.views.uploadFile'),
    url(r'^upload/file/$', views.upload,
        name='Theophrastus.views.upload'),
    url(r'^facebook/feed/complete/$', views.feedComplete,
        name="Theophrastus.facebook.feed.complete"),
)
